@@ -218,8 +218,8 @@ class FileUpload:
         return hash(self._to_dict())
 
 
-FileDescriptor = namedtuple('FileDescriptor', ['download_url', 'description', 'name', 'show_delete_button'])
-TeamFileDescriptor = namedtuple('TeamFileDescriptor', ['download_url', 'description', 'name', 'uploaded_by'])
+FileDescriptor = namedtuple('FileDescriptor', ['download_url', 'description', 'name', 'size', 'show_delete_button'])
+TeamFileDescriptor = namedtuple('TeamFileDescriptor', ['download_url', 'description', 'name', 'size', 'uploaded_by'])
 
 
 class FileUploadManager:
@@ -242,7 +242,7 @@ class FileUploadManager:
     """
     def __init__(self, openassessment_xblock):
         self.block = openassessment_xblock
-        self.shared_uploads_for_team_by_key_cache = dict()
+        self.shared_uploads_for_team_by_key_cache = {}
 
     @cached_property
     def student_item_dict(self):
@@ -343,6 +343,7 @@ class FileUploadManager:
                 download_url=upload.download_url,
                 description=upload.description,
                 name=upload.name,
+                size=upload.size,
                 show_delete_button=show_delete_button,
             )._asdict())
 
@@ -358,6 +359,7 @@ class FileUploadManager:
                 download_url=upload.download_url,
                 description=upload.description,
                 name=upload.name,
+                size=upload.size,
                 uploaded_by=self.block.get_username(upload.student_id)
             )._asdict()
             for upload in self.get_team_uploads(team_id=team_id)
@@ -398,7 +400,7 @@ class FileUploadManager:
         if hasattr(self, 'shared_uploads_for_student_by_key'):
             del self.shared_uploads_for_student_by_key
 
-        self.shared_uploads_for_team_by_key_cache = dict()
+        self.shared_uploads_for_team_by_key_cache = {}
 
     def append_uploads(self, *new_uploads):
         """
